SPDCalc Python Package Documentation
====================================

.. toctree::
   :hidden:

   Home <self>

.. toctree::
  :maxdepth: 2

  quickstart
  api

  GitHub Repo <https://github.com/spdcalc/spdcalc-py>
  Changelog <https://github.com/spdcalc/spdcalc-py/releases>
  PyPI <https://pypi.org/project/spdcalc-py>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
